@@ -1,4 +1,4 @@
-/* $Id: hparser.c,v 2.57 2001/03/13 19:22:14 gisle Exp $
+/* $Id: hparser.c,v 2.59 2001/03/19 04:49:42 gisle Exp $
  *
  * Copyright 1999-2001, Gisle Aas
  * Copyright 1999-2000, Michael A. Chase
@@ -336,8 +336,10 @@ report_event(PSTATE* p_state,
 	    if (event == E_START) {
 		HV* hv;
 		int i;
-		if (argcode == ARG_ATTR)
+		if (argcode == ARG_ATTR) {
 		    hv = newHV();
+		    arg = sv_2mortal(newRV_noinc((SV*)hv));
+		}
 		else
 		    push_arg = 0;  /* deal with argument pushing here */
 
@@ -383,8 +385,6 @@ report_event(PSTATE* p_state,
 			}
 		    }
 		}
-		if (argcode == ARG_ATTR)
-		    arg = sv_2mortal(newRV_noinc((SV*)hv));
 	    }
 	    else if (argcode == ARG_ATTRARR) {
 		push_arg = 0;
@@ -1236,7 +1236,7 @@ parse(pTHX_
     STRLEN len;
 
     if (!chunk) {
-	/* flush */
+	/* eof */
 	if (p_state->buf && SvOK(p_state->buf)) {
 	    /* flush it */
 	    STRLEN len;
@@ -1249,6 +1249,12 @@ parse(pTHX_
 	}
 	if (p_state->pend_text && SvOK(p_state->pend_text))
 	    flush_pending_text(p_state, self);
+
+	if (p_state->ignoring_element) {
+	    /* document not balanced */
+	    SvREFCNT_dec(p_state->ignoring_element);
+	    p_state->ignoring_element = 0;
+	}
 	return;
     }
 
